<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui version="10" name="plasmate" >
<MenuBar>

    <Menu name="edit">
    <text context="@title:menu">&amp;Edit</text>
    <DefineGroup append="edit_undo_merge" name="edit_undo_merge"/>
    <DefineGroup append="edit_paste_merge" name="edit_paste_merge"/>
    <DefineGroup append="edit_select_merge" name="edit_select_merge"/>
    <DefineGroup append="edit_find_merge" name="edit_find_merge"/>
    <DefineGroup name="edit_formatting"/>
    <Separator/>
    <Merge/>
  </Menu>

  <Merge />

  <Menu name="editor">
    <text context="@title:menu">Editor</text>
    <Merge/>
  </Menu>

  <Menu name="navigation">
    <text context="@title:menu">&amp;Navigation</text>
    <DefineGroup name="navigation_file"/>
    <Separator />
    <Action name="previous_error" />
    <Action name="next_error" />
    <Separator />
    <DefineGroup name="navigation_code"/>
    <Separator />
    <DefineGroup name="navigation_fxn"/>
    <Separator />
    <DefineGroup name="navigation_jmp"/>
    <Separator />
    <DefineGroup name="navigation_use"/>
    <Separator />
    <DefineGroup name="navigation_cxt"/>
    <Separator />
    <Merge />
  </Menu>

  <Menu name="code">
    <text context="@title:menu">Code</text>
  </Menu>

  <Menu name="window">
    <text context="@title:menu">&amp;Window</text>
    <Action name="new_window"/>
    <Separator/>
    <Action name="add_toolview"/>
    <Action name="select_previous_dock"/>
    <Action name="select_next_dock"/>
    <Action name="docks_submenu"/>
    <Action name="user_interface"/>
    <DefineGroup name="history_operations"/>
    <Action name="history_back"/>
    <Action name="history_forward"/>
    <Separator/>
    <Action name="file_switchto"/>
    <Separator/>
    <DefineGroup name="error_operations"/>
    <Separator/>
    <Merge/>
    <Separator/>
    <DefineGroup name="view_operations"/>
    <Action name="view_previous_window"/>
    <Action name="view_next_window"/>
    <Separator/>
    <Action name="split_horizontal"/>
    <Action name="split_vertical"/>
    <Action name="view_previous_split"/>
    <Action name="view_next_split"/>
    <Separator/>
    <DefineGroup name="window_operations"/>
    <Separator/>
    <Action name="focus_editor"/>
    <Separator/>
    <Action name="show_left_dock"/>
    <Action name="show_right_dock"/>
    <Action name="show_bottom_dock"/>
    <Action name="hide_all_docks"/>
    <Separator/>
    <Merge/>
  </Menu>

  <Menu name="settings">
    <text context="@title:menu">Settings</text>
    <DefineGroup append="show_toolbar_merge" name="show_toolbar_merge"/>
    <DefineGroup append="show_merge" name="show_merge" />
    <Action name="show_editorconfig" append="configure_merge" />
    <DefineGroup append="configure_merge" name="configure_merge" />
  </Menu>

  <Menu name="help">
    <Action name="loaded_plugins" append="about_merge" />
    <Action name="about_platform" append="about_merge" />
  </Menu>

</MenuBar>


</kpartgui>
